=== modified file 'NEWS'
--- NEWS	2005-10-09 22:59:39 +0000
+++ NEWS	2005-10-09 23:52:04 +0000
@@ -59,6 +59,10 @@
 
     * 'rm' is now an alias for 'remove'.
 
+    * Stores now split out their content in a single byte prefixed hash,
+      dropping the density of files per directory by 256. Contributed by
+      Gustavo Niemeyer.
+
 
   INTERNALS:
 

=== modified file 'bzrlib/selftest/test_upgrade.py'
--- bzrlib/selftest/test_upgrade.py	2005-10-09 23:42:12 +0000
+++ bzrlib/selftest/test_upgrade.py	2005-10-09 23:52:04 +0000
@@ -77,8 +77,11 @@
     def test_upgrade_makes_dir_weaves(self):
         build_tree_contents(_upgrade_dir_template)
         upgrade('.')
+        # this is the path to the literal file. As format changes 
+        # occur it needs to be updated. FIXME: ask the store for the
+        # path.
         self.failUnlessExists(
-            '.bzr/weaves/dir-20051005095101-da1441ea3fa6917a.weave')
+            '.bzr/weaves/de/dir-20051005095101-da1441ea3fa6917a.weave')
 
 
 _upgrade1_template = \

=== modified file 'bzrlib/selftest/testfetch.py'
--- bzrlib/selftest/testfetch.py	2005-10-08 00:03:38 +0000
+++ bzrlib/selftest/testfetch.py	2005-10-09 23:52:04 +0000
@@ -135,6 +135,9 @@
         source = Branch.open(self.get_remote_url("source/"))
         source.weave_store.enable_cache = False
         self.assertEqual(greedy_fetch(target, source), (2, []))
-        weave_suffix = 'weaves/id.weave HTTP/1.1" 200 -'
+        # this is the path to the literal file. As format changes 
+        # occur it needs to be updated. FIXME: ask the store for the
+        # path.
+        weave_suffix = 'weaves/ce/id.weave HTTP/1.1" 200 -'
         self.assertEqual(1,
             len([log for log in self.weblogs if log.endswith(weave_suffix)]))

=== modified file 'bzrlib/store/__init__.py'
--- bzrlib/store/__init__.py	2005-10-09 23:42:12 +0000
+++ bzrlib/store/__init__.py	2005-10-09 23:52:04 +0000
@@ -25,6 +25,7 @@
 """
 
 from cStringIO import StringIO
+from stat import ST_MODE, S_ISDIR
 from zlib import adler32
 
 from bzrlib.errors import BzrError, UnlistableStore, TransportNotPossible
@@ -205,6 +206,19 @@
 
     __str__ = __repr__
 
+    def _iter_relpaths(self):
+        """Iter the relative paths of files in the transports sub-tree."""
+        transport = self._transport
+        queue = list(transport.list_dir('.'))
+        while queue:
+            relpath = queue.pop(0)
+            st = transport.stat(relpath)
+            if S_ISDIR(st[ST_MODE]):
+                for i, basename in enumerate(transport.list_dir(relpath)):
+                    queue.insert(i, relpath+'/'+basename)
+            else:
+                yield relpath, st
+
     def listable(self):
         """Return True if this store is able to be listed."""
         return self._transport.listable()

=== modified file 'bzrlib/store/compressed_text.py'
--- bzrlib/store/compressed_text.py	2005-10-09 23:42:12 +0000
+++ bzrlib/store/compressed_text.py	2005-10-09 23:52:04 +0000
@@ -29,7 +29,7 @@
 from bzrlib.errors import BzrError, FileExists
 
 from StringIO import StringIO
-from stat import ST_SIZE, ST_MODE, S_ISDIR
+from stat import ST_SIZE
 
 class CompressedTextStore(bzrlib.store.TransportStore):
     """Store that holds files indexed by unique names.
@@ -206,18 +206,6 @@
             yield None
             count += 1
 
-    def _iter_relpaths(self):
-        transport = self._transport
-        queue = list(transport.list_dir('.'))
-        while queue:
-            relpath = queue.pop(0)
-            st = transport.stat(relpath)
-            if S_ISDIR(st[ST_MODE]):
-                for i, basename in enumerate(transport.list_dir(relpath)):
-                    queue.insert(i, relpath+'/'+basename)
-            else:
-                yield relpath, st
-
     def __iter__(self):
         for relpath, st in self._iter_relpaths():
             if relpath.endswith(".gz"):

=== modified file 'bzrlib/store/text.py'
--- bzrlib/store/text.py	2005-10-09 23:42:12 +0000
+++ bzrlib/store/text.py	2005-10-09 23:52:04 +0000
@@ -29,7 +29,7 @@
 from bzrlib.errors import BzrError, FileExists
 
 from cStringIO import StringIO
-from stat import ST_SIZE, ST_MODE, S_ISDIR
+from stat import ST_SIZE
 
 
 class TextStore(bzrlib.store.TransportStore):
@@ -137,18 +137,6 @@
             yield None
             count += 1
 
-    def _iter_relpaths(self):
-        transport = self._transport
-        queue = list(transport.list_dir('.'))
-        while queue:
-            relpath = queue.pop(0)
-            st = transport.stat(relpath)
-            if S_ISDIR(st[ST_MODE]):
-                for i, basename in enumerate(transport.list_dir(relpath)):
-                    queue.insert(i, relpath+'/'+basename)
-            else:
-                yield relpath, st
-
     def __iter__(self):
         for relpath, st in self._iter_relpaths():
             yield os.path.basename(relpath)

=== modified file 'bzrlib/store/weave.py'
--- bzrlib/store/weave.py	2005-10-09 23:42:12 +0000
+++ bzrlib/store/weave.py	2005-10-09 23:52:04 +0000
@@ -21,19 +21,18 @@
 
 
 from cStringIO import StringIO
-from stat import ST_MODE, S_ISDIR
 import os
 import errno
 
 from bzrlib.weavefile import read_weave, write_weave_v5
 from bzrlib.weave import Weave
-from bzrlib.store import Store, hash_prefix
+from bzrlib.store import TransportStore, hash_prefix
 from bzrlib.atomicfile import AtomicFile
 from bzrlib.errors import NoSuchFile, FileExists
 from bzrlib.trace import mutter
 
 
-class WeaveStore(Store):
+class WeaveStore(TransportStore):
     """Collection of several weave files in a directory.
 
     This has some shortcuts for reading and writing them.
@@ -51,18 +50,6 @@
         else:
             return file_id + WeaveStore.FILE_SUFFIX
 
-    def _iter_relpaths(self):
-        transport = self._transport
-        queue = list(transport.list_dir('.'))
-        while queue:
-            relpath = queue.pop(0)
-            st = transport.stat(relpath)
-            if S_ISDIR(st[ST_MODE]):
-                for i, basename in enumerate(transport.list_dir(relpath)):
-                    queue.insert(i, relpath+'/'+basename)
-            else:
-                yield relpath, st
-
     def __iter__(self):
         l = len(WeaveStore.FILE_SUFFIX)
         for relpath, st in self._iter_relpaths():

